EmbyPy EmbyObject
=====================

.. automodule:: embypy.objects
  :show-inheritance:

.. autosummary::
  EmbyObject
  EmbyObject.id
  EmbyObject.name
  EmbyObject.path
  EmbyObject.type
  EmbyObject.media_type
  EmbyObject.genres
  EmbyObject.tags
  EmbyObject.overview
  EmbyObject.primary_image_url
  EmbyObject.community_rating
  EmbyObject.primary_image_url
  EmbyObject.parent
  EmbyObject.url
  EmbyObject.update
  EmbyObject.send
  EmbyObject.process

.. autoclass:: EmbyObject
   :members:
